@@ -1,6 +1,6 @@
 from maleo.mixins.parameter import (
     Filters,
-    ListOfDataStatuses,
+    DataStatuses,
     Sorts,
     Search,
     UseCache,
@@ -9,36 +9,36 @@ from maleo.mixins.parameter import (
 from maleo.dtos.pagination import BaseFlexiblePagination, BaseStrictPagination
 
 
-class ReadSingleQueryParameter(
-    ListOfDataStatuses,
+class ReadSingleQuery(
+    DataStatuses,
     UseCache,
 ):
     pass
 
 
-class BaseReadMultipleQueryParameter(
+class BaseReadMultipleQuery(
     Sorts,
     Search,
-    ListOfDataStatuses,
+    DataStatuses,
     Filters,
     UseCache,
 ):
     pass
 
 
-class ReadUnpaginatedMultipleQueryParameter(
+class ReadUnpaginatedMultipleQuery(
     BaseFlexiblePagination,
-    BaseReadMultipleQueryParameter,
+    BaseReadMultipleQuery,
 ):
     pass
 
 
-class ReadPaginatedMultipleQueryParameter(
+class ReadPaginatedMultipleQuery(
     BaseStrictPagination,
-    BaseReadMultipleQueryParameter,
+    BaseReadMultipleQuery,
 ):
     pass
 
 
-class StatusUpdateQueryParameter(StatusUpdateAction):
+class StatusUpdateBody(StatusUpdateAction):
     pass
